-- #############################################################################
-- ## Module: @(#)mk_qa_check.sql      1.0     Date: 2020/05/18
-- ## Author: Lester Knutsen  Email: lester@advancedatatools.com
-- ##         Advanced DataTools Corporation
-- #############################################################################

-- #############################################################################
-- Script to generate QA scripts for your data based on:
--	1. Count of rows in table
--	2. Sum of first Decimal Column in the table
-- #############################################################################

-- Create a table to identify one decimal column per table to sum for QA
drop table if exists tmp_key_columns;
create temp table tmp_key_columns(
                t_name  varchar(128),
                t_id    integer,
                c_name  varchar(128)
                );

-- Identify all tables and any decimal columns
insert into tmp_key_columns
select unique tabname, systables.tabid, syscolumns.colname
from systables, outer syscolumns
where  systables.tabid = syscolumns.tabid
and systables.tabid > 99
and syscolumns.coltype = 5
and tabtype = "T";

-- Update any columns which are null
update tmp_key_columns set c_name = "0" where c_name is null;

-- Identify one decimal column per table
select t_name, t_id, max (c_name) c_name
from tmp_key_columns
group by 1, 2
into temp tmp_key_columns2 ;

-- Build a QA script to count rows and sum the decimal columns
output to "qa_data_check.sql" without headings
select "select '" || trim(tabname) || "', count(*), sum( " ||
        trim((select c_name from tmp_key_columns2 where t_id = tabid) )
        || " ) from " || trim(tabname) || ";"
from systables
where tabid > 99
and tabtype ="T";
